import java.io.*;
import java.util.*;

public class  {
    private static final String INPUT_FILE = "disconnected.in";
    private static final String OUTPUT_FILE = "disconnected.out";
    private static final int MAXN = 10000;
    private static final int MAXM = 100000;
    private static final int MAXK = 100000;
    private static final int MAXC = 4;
    private static final int RANDOM_SEED = 172312;

    public static void main(String[] a) throws IOException {
        new ().run();
    }

    private void run() throws IOException {
        BufferedReader input = new BufferedReader(new FileReader(INPUT_FILE));
        PrintWriter output = new PrintWriter(new File(OUTPUT_FILE));
        StringTokenizer st = new StringTokenizer(input.readLine());
        int n = Integer.parseInt(st.nextToken());
        int m = Integer.parseInt(st.nextToken());
        if (n < 1 || n > MAXN) {
            throw new RuntimeException("invalid n");
        }
        if (m < 1 || m > MAXM) {
            throw new RuntimeException("invalid m");
        }
        HashSet<Pair> was = new HashSet<Pair>();
        ArrayList<Pair>[] e = new ArrayList[n];
        for (int i = 0; i < n; i++) {
            e[i] = new ArrayList<Pair>();
        }
        for (int i = 0; i < m; i++) {
            st = new StringTokenizer(input.readLine());
            int a = Integer.parseInt(st.nextToken());
            int b = Integer.parseInt(st.nextToken());
            if (a < 1 || a > n || b < 1 || b > n || a == b) {
                throw new RuntimeException("invalid edge ends");
            }
            if (a > b) {
                int t = a;
                a = b;
                b = t;
            }
            Pair pair = new Pair(a, b);
            if (was.contains(pair)) {
                throw new RuntimeException("parallel edges");
            }
            was.add(pair);
            a--;
            b--;
            e[a].add(new Pair(b, i));
            e[b].add(new Pair(a, i));
        }
        boolean[] mark = new boolean[n];
        boolean[] isInST = new boolean[m];
        for (int i = 0; i < n; i++) {
            if (mark[i]) {
                continue;
            }
            if (i != 0) {
                throw new RuntimeException("graph is not connected");
            }
            BuildST(e, i, mark, isInST);
        }
        long[] mask = new long[m];
        Random random = new Random(RANDOM_SEED);
        for (int i = 0; i < m; i++) {
            if (isInST[i]) {
                continue;
            }
            mask[i] = random.nextLong();
        }
        Arrays.fill(mark, false);
        ComputeMasks(e, 0, mark, mask);
        for (int i = 0; i < n; i++) {
            long sum = 0;
            for (Pair edge: e[i]) {
                sum ^= mask[edge.b];
            }
            if (sum != 0) {
                throw new RuntimeException("shit happened");
            }
        }
        st = new StringTokenizer(input.readLine());
        int k = Integer.parseInt(st.nextToken());
        if (k < 1 || k > MAXK) {
            throw new RuntimeException("invalid k");
        }
        for (int i = 0; i < k; i++) {
            st = new StringTokenizer(input.readLine());
            int c = Integer.parseInt(st.nextToken());
            if (c < 1 || c > MAXC) {
                throw new RuntimeException("invalid c");
            }
            int[] query = new int[c];
            for (int j = 0; j < c; j++) {
                query[j] = Integer.parseInt(st.nextToken());
                if (query[j] < 1 || query[j] > m) {
                    throw new RuntimeException("invalid query content");
                }
                query[j]--;
            }
            Arrays.sort(query);
            for (int j = 0; j < c - 1; j++) {
                if (query[j] == query[j + 1]) {
                    throw new RuntimeException("query's elements are not distinct");
                }
            }
            boolean connected = true;
            for (int j = 1; j < (1 << c); j++) {
                long sum = 0;
                for (int l = 0; l < c; l++) {
                    if (((j >> l) & 1) == 0) {
                        continue;
                    }
                    sum ^= mask[query[l]];
                }
                if (sum == 0) {
                    connected = false;
                    break;
                }
            }
            output.println(connected ? "Connected" : "Disconnected");
        }
        input.close();
        output.close();
    }

    private void ComputeMasks(ArrayList<Pair>[] e, int node, boolean[] mark, long[] mask) {
        int[] stack = new int[e.length];
        int[] incomingID = new int[e.length];
        int sp = 1;
        stack[0] = node;
        mark[node] = true;
        incomingID[node] = -1;
        while (sp > 0) {
            node = stack[sp - 1];
            boolean anyChange = false;
            for (Pair edge: e[node]) {
                int to = edge.a;
                int id = edge.b;
                if (mark[to]) {
                    continue;
                }
                mark[to] = true;
                anyChange = true;
                incomingID[to] = id;
                stack[sp++] = to;
            }
            if (!anyChange) {
                --sp;
                long sum = 0;
                for (Pair edge: e[node]) {
                    int id = edge.b;
                    sum ^= mask[id];
                }
                if (incomingID[node] == -1 && sum != 0) {
                    throw new RuntimeException("shit happened");
                }
                if (incomingID[node] != -1) {
                    mask[incomingID[node]] = sum;
                }
            }
        }
    }

    private void BuildST(ArrayList<Pair>[] e, int node, boolean[] mark, boolean[] isInST) {
        int[] stack = new int[e.length];
        int sp = 1;
        stack[0] = node;
        mark[node] = true;
        while (sp > 0) {
            node = stack[--sp];
            for (Pair edge: e[node]) {
                int to = edge.a;
                int id = edge.b;
                if (mark[to]) {
                    continue;
                }
                mark[to] = true;
                isInST[id] = true;
                stack[sp++] = to;
            }
        }
    }

    class Pair {
        public int a, b;

        Pair(int a, int b) {
            this.a = a;
            this.b = b;
        }

        @Override
        public boolean equals(Object o) {
            Pair pair = (Pair) o;

            if (a != pair.a) return false;
            if (b != pair.b) return false;

            return true;
        }

        @Override
        public int hashCode() {
            int result = a;
            result = 31 * result + b;
            return result;
        }
    }
}
