#include <iostream>
#include <vector>
#include <cstdio>
#include <algorithm>

using namespace std;

int n, m;

vector<pair<int, int> > edges;
vector<bool> in_tree;
vector<bool> used;
vector<int> tin;
vector<int> tout;
vector<vector<int> > g;
vector<vector<int> > num;
vector<vector<int> > reff;
vector<int> next;

int time = 0;

void dfs(int v) {
    used[v] = true;
    tin[v] = time++;

    for (int i = 0; i < g[v].size(); ++i) {
        int u = g[v][i];
        if (!used[u]) {
            in_tree[num[v][i]] = true;
            dfs(u);
        } else {
            reff[u].push_back(num[v][i]);
        }
    }

    tout[v] = time++;
}

void calc_next(int v, int pr) {
    next[v] = pr;
    used[v] = true;

    for (int i = 0; i < g[v].size(); ++i) {
        int u = g[v][i];
        if (!in_tree[num[v][i]]) continue;
        if (!used[u]) {
            calc_next(u, reff[v].size() == 0 ? pr : v);
        }
    }
}

bool try_solve(int num_x, vector<int> & a) {
    int v = edges[num_x].first;
    int u = edges[num_x].second;

    if (tin[v] > tin[u]) swap(v, u);

    int last_v = 0;

    for (int i = 0; i < a.size(); ++i) {
        int tmp_v = edges[a[i]].first;
        int tmp_u = edges[a[i]].second;
        if (tin[tmp_v] > tin[tmp_u]) swap(tmp_v, tmp_u);
        if (tin[tmp_v] <= tin[v] && tout[v] <= tout[tmp_v]) {
            last_v = tmp_v;
        }
    }

//    cerr << v << " " << u << endl;

    while (v != -1) {
        for (int i = 0; i < reff[v].size(); ++i) {
            if (find(a.begin(), a.end(), reff[v][i]) == a.end()) {
//                cerr << reff[v][i] << endl;
                pair<int, int> edge = edges[reff[v][i]];
                int other = (v == edge.first ? edge.second : edge.first);
                if (tin[u] <= tin[other] && tin[other] <= tout[u]) {
//                    cerr << "Ooops!" << endl;
                    return true;
                }
            }
        }
        v = next[v];
        if (tin[v] < tin[last_v])
            break;
    }

    return false;
}

int main()
{
    freopen("disconnected.in","r",stdin);
    freopen("disconnected.out","w",stdout);

    cin >> n >> m;
    edges.resize(m);
    used.resize(n);
    tin.resize(n);
    tout.resize(n);
    in_tree.resize(m);
    g.resize(n);
    num.resize(n);
    reff.resize(n);
    next.resize(n);

    for (int i = 0; i < m; ++i) {
        int v, u;
        cin >> v >> u;
        --v, --u;
        g[v].push_back(u);
        g[u].push_back(v);
        num[v].push_back(i);
        num[u].push_back(i);
        edges[i] = make_pair(v, u);
    }

    dfs(0);
    used.clear();
    used.resize(n, false);
    calc_next(0, -1);

    int k;
    cin >> k;
    while (k--) {
        int c;
        cin >> c;
        vector<int> a(c);
        for (int i = 0; i < c; ++i) {
            cin >> a[i];
            --a[i];
        }

        bool flag = true;

        for (int i = 0; i < c; ++i)
            if (in_tree[a[i]])
                flag &= try_solve(a[i], a);

        cout << (flag ? "Connected" : "Disconnected") << endl;
    }

    return 0;
}
