#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>

#include <iostream>
#include <iomanip>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <deque>
#include <queue>
#include <stack>
#include <algorithm>


#define forn(i, n) for(int i = 0; i < int(n); i++)
#define mp make_pair
#define pb push_back
#define foreach(it, v) for(__typeof(v.begin()) it = v.begin(); it != v.end(); ++it)

using namespace std;

typedef long long ll;

const int BUBEN = 250;
const int MAXN = 10000, MAXM = 100000;
const int MAXK = 4;

typedef pair < int, int > edge_t;

int n, m, q;
edge_t edges[MAXM];
bool isRemoved[MAXM];
int removedIds[BUBEN * MAXK], removedIdsGood[BUBEN * MAXK];
int queriesIds[MAXM][MAXK];
int queriesSize[MAXM];
bool results[MAXM];
int dsu[MAXN];
int isRemovedCurrent[MAXM];
int components;

inline int dsuFind(int a) {
	if(dsu[a] == a) return a;
	return dsu[a] = dsuFind(dsu[a]);
}

void dsuUnion(int a, int b) {
	a = dsuFind(a);
	b = dsuFind(b);
	if(a != b) {
		--components;
		dsu[b] = a;
	}
}

typedef pair < int, int > record_t;

int operationsCount;
record_t operations[MAXM];

inline int dsuFindHistory(int a) {
	if(dsu[a] == a) return a;
	operations[operationsCount++] = mp(a, dsu[a]);
	return dsu[a] = dsuFindHistory(dsu[a]);
}

inline void dsuUnionHistory(int a, int b) {
	a = dsuFindHistory(a);
	b = dsuFindHistory(b);
	//printf("UNION: %d %d\n", a, b);
	if(a != b) {
		--components;
		operations[operationsCount++] = mp(a, dsu[a]);
		dsu[a] = b;
	}
}

void stackClear() {
	operationsCount = 0;
}

void stackReverse() {
	for(int i = operationsCount - 1; i >= 0; i--) {
		record_t op = operations[i];
		dsu[op.first] = op.second;
	}
}

int p[MAXM];

int main() {
	srand(1123131);
	scanf("%d%d", &n, &m);
	for(int i = 0; i < m; i++) {
		scanf("%d%d", &edges[i].first, &edges[i].second);
		--edges[i].first;
		--edges[i].second;
		if(rand() & 1) swap(edges[i].first, edges[i].second);
	}
	scanf("%d", &q);
	for(int i = 0; i < q; i++) {
		scanf("%d", &queriesSize[i]);
		for(int k = 0; k < queriesSize[i]; k++) {
			scanf("%d", &queriesIds[i][k]);
			--queriesIds[i][k];
		}
		sort(queriesIds[i], queriesIds[i] + queriesSize[i]);
		p[i] = i;
	}
	random_shuffle(p, p + q);
	for(int i = 0; i < q; i += BUBEN) {
		int cq = min(BUBEN, q - i);
		memset(isRemoved, 0, sizeof(isRemoved));
		int bc = 0;
		for(int j = 0; j < cq; j++) {
			int id = p[j];
			for(int k = 0; k < queriesSize[id]; k++) {
				isRemoved[queriesIds[id][k]] = true;
				removedIds[bc++] = queriesIds[id][k];
			}
		}
		for(int j = 0; j < n; j++) {
			dsu[j] = j;
		}
		components = n;
		for(int j = 0; j < m; j++) {
			if(!isRemoved[j]) {
				dsuUnion(edges[j].first, edges[j].second);
			}
		}
		for(int j = 0; j < n; j++) {
			dsu[j] = dsuFind(j);
		}
		int bcGood = 0;
		for(int j = 0; j < bc; j++) {
			int edgeId = removedIds[j];
			if(dsuFind(edges[edgeId].first) != dsuFind(edges[edgeId].second)) {
				removedIdsGood[bcGood++] = edgeId;
			}
		}
		random_shuffle(removedIdsGood, removedIdsGood + bcGood);
		for(int j = 0; j < cq; j++) {
			//printf("QUERY: %d\n", j);
			int timer = i + j + 1;
			int componentsBefore = components;
			stackClear();
			int id = p[j];
			for(int k = 0; k < queriesSize[id]; k++) {
				isRemovedCurrent[queriesIds[id][k]] = timer;
			}
			for(int k = 0; k < bcGood && components > 1; k++) {
				int minComponents = components - (bcGood - k);
				if(minComponents > 1) break;
				int edgeId = removedIdsGood[k];
				if(isRemovedCurrent[edgeId] != timer) {
					//printf("MERGE: %d %d\n", edges[edgeId].first, edges[edgeId].second);
					dsuUnionHistory(edges[edgeId].first, edges[edgeId].second);
				}
			}
			//printf("After: %d\n", components);
			stackReverse();
			results[id] = (components == 1);
			components = componentsBefore;
		}
	}
	for(int i = 0; i < q; i++) {
		if(results[i]) printf("Connected\n");
		else printf("Disconnected\n");
	}
	return 0;
}