#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>
#include <ctime>

#include <iostream>
#include <iomanip>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <deque>
#include <queue>
#include <stack>
#include <algorithm>


#define forn(i, n) for(int i = 0; i < int(n); i++)
#define mp make_pair
#define pb push_back
#define foreach(it, v) for(__typeof(v.begin()) it = v.begin(); it != v.end(); ++it)

using namespace std;

typedef long long ll;

const int BUBEN = 150;
const int MAXN = 10000, MAXM = 100000;
const int MAXK = 4;

typedef pair < int, int > edge_t;

int n, m, q;
edge_t edges[MAXM];
bool isRemoved[MAXM];
int removedIds[BUBEN * MAXK], removedIdsGood[BUBEN * MAXK];
int queriesIds[BUBEN][MAXK];
int queriesSize[BUBEN];
bool results[MAXM];
int dsu[MAXN], dsuRanks[MAXN];
int isRemovedCurrent[MAXM];
int components;

inline int dsuFind(int a) {
	if(dsu[a] == a) return a;
	return dsu[a] = dsuFind(dsu[a]);
}

void dsuUnion(int a, int b) {
	a = dsuFind(a);
	b = dsuFind(b);
	if(a != b) {
		--components;
		if(dsuRanks[a] > dsuRanks[b]) swap(a, b);
		dsu[b] = a;
		++dsuRanks[a];
	}
}

typedef pair < int, int > record_t;

int operationsCount;
record_t operations[MAXM];
int operationsRanks[MAXM];

inline int dsuFindHistory(int a) {
	if(dsu[a] == a) return a;
	operations[operationsCount++] = mp(a, dsu[a]);
	return dsu[a] = dsuFindHistory(dsu[a]);
}

inline void dsuUnionHistory(int a, int b) {
	a = dsuFindHistory(a);
	b = dsuFindHistory(b);
	//printf("UNION: %d %d\n", a, b);
	if(a != b) {
		--components;
		if(dsuRanks[a] > dsuRanks[b]) swap(a, b);
		
		operations[operationsCount] = mp(b, dsu[b]);
		operationsRanks[operationsCount] = a;
		++operationsCount;
		
		dsu[b] = a;
		++dsuRanks[a];
	}
}

void stackClear() {
	operationsCount = 0;
}

void stackReverse() {
	for(int i = operationsCount - 1; i >= 0; i--) {
		record_t op = operations[i];
		dsu[op.first] = op.second;
		--dsuRanks[operationsRanks[i]];
	}
}

int main() {
	srand(11211);
	scanf("%d%d", &n, &m);
	clock_t start = clock();
	for(int i = 0; i < n; i++) {
		dsu[i] = i;
		dsuRanks[i] = 1;
	}
	components = n;
	for(int i = 0; i < m; i++) {
		scanf("%d%d", &edges[i].first, &edges[i].second);
		--edges[i].first;
		--edges[i].second;
		if(rand() & 1) swap(edges[i].first, edges[i].second);
		dsuUnion(edges[i].first, edges[i].second);
	}
	if(components == 1) {
		scanf("%d", &q);
		for(int i = 0; i < q; i += BUBEN) {
			int cq = min(BUBEN, q - i);
			memset(isRemoved, 0, sizeof(isRemoved));
			int bc = 0;
			for(int j = 0; j < cq; j++) {
				scanf("%d", &queriesSize[j]);
				for(int k = 0; k < queriesSize[j]; k++) {
					scanf("%d", &queriesIds[j][k]);
					--queriesIds[j][k];
					isRemoved[queriesIds[j][k]] = true;
					removedIds[bc++] = queriesIds[j][k];
				}
			}
			for(int j = 0; j < n; j++) {
				dsu[j] = j;
			}
			components = n;
			for(int j = 0; j < m; j++) {
				if(!isRemoved[j]) {
					dsuUnion(edges[j].first, edges[j].second);
				}
			}
			for(int j = 0; j < n; j++) {
				dsu[j] = dsuFind(j);
			}
			int bcGood = 0;
			for(int j = 0; j < bc; j++) {
				int edgeId = removedIds[j];
				if(dsuFind(edges[edgeId].first) != dsuFind(edges[edgeId].second)) {
					removedIdsGood[bcGood++] = edgeId;
				}
			}
			random_shuffle(removedIdsGood, removedIdsGood + bcGood);
			for(int j = 0; j < cq; j++) {
				//printf("QUERY: %d\n", j);
				int timer = i + j + 1;
				int componentsBefore = components;
				stackClear();
				for(int k = 0; k < queriesSize[j]; k++) {
					isRemovedCurrent[queriesIds[j][k]] = timer;
				}
				for(int k = 0; k < bcGood && components > 1; k++) {
					int minComponents = components - (bcGood - k);
					if(minComponents > 1) break;
					int edgeId = removedIdsGood[k];
					if(isRemovedCurrent[edgeId] != timer) {
						//printf("MERGE: %d %d\n", edges[edgeId].first, edges[edgeId].second);
						dsuUnionHistory(edges[edgeId].first, edges[edgeId].second);
					}
				}
				//printf("After: %d\n", components);
				stackReverse();
				results[i + j] = (components == 1);
				components = componentsBefore;
			}
		}
	}
	double total = double(clock() - start) / CLOCKS_PER_SEC;
	//cout << total << endl;
	for(int i = 0; i < q; i++) {
		if(results[i]) printf("Connected\n");
		else printf("Disconnected\n");
	}
	return 0;
}