#include <iostream>
#include <cstdio>
#include <algorithm>
#include <vector>
#include <cstring>
using namespace std;

struct union_find {
    int *p;
    union_find(int n) {
        p = new int[n];
        memset(p, -1, n * sizeof(int));
    }

    int find(int x) {
        return p[x] < 0 ? x : p[x] = find(p[x]);
    }

    bool unite(int x, int y) {
        int xp = find(x),
            yp = find(y);

        if (xp == yp) return false;
        if (p[xp] < p[yp]) p[xp] += p[yp], p[yp] = xp;
        else p[yp] += p[xp], p[xp] = yp;
        return true;
    }
    int size(int x) {
        return -p[find(x)];
    }
};

void readn(register int *n) {
    register char c;
    *n = 0;
    while (true) {
        //c = getc_unlocked(stdin);
        c = getc(stdin);
        switch (c) {
            case ' ': 
            case '\n': 
                return;
            default:
                *n = *n * 10 + c - '0';
                break;
        }
    }
}

int main() {
    int n, m;
    readn(&n);
    readn(&m);

    int *xs = new int[m];
    int *ys = new int[m];
    for (int i = 0; i < m; i++) {
        readn(xs + i);
        readn(ys + i);
        xs[i]--;
        ys[i]--;
    }

    bool *used = new bool[m];
    bool *in_tree = new bool[m];
    pair<int, int> *occ = new pair<int, int>[m];
    memset(in_tree, 0, m);

    for (int i = 0; i < m; i++) {
        occ[i].second = i;
    }

    int cnt;
    readn(&cnt);

    int *queries[5];
    for (int i = 0; i < 5; i++) {
        queries[i] = new int[cnt];
    }

    for (int i = 0; i < cnt; i++) {
        int c;
        readn(&c);
        queries[4][i] = c;

        for (int j = 0; j < c; j++) {
            readn(&queries[j][i]);
            queries[j][i]--;
            occ[queries[j][i]].first++;
        }

    }

    sort(occ, occ + m);

    union_find uf(n);
    for (int i = 0, es = 0; i < m && es < n - 1; i++) {
        int a = xs[occ[i].second],
            b = ys[occ[i].second];

        if (uf.find(a) != uf.find(b)) {
            uf.unite(a, b);
            in_tree[occ[i].second] = true;
            es++;
        }
    }

    int no[4];
    for (int i = 0; i < cnt; i++) {
        memset(uf.p, -1, n * sizeof(int));

        int c = queries[4][i];

        bool any = false;

        for (int j = 0; j < c; j++) {
            no[j] = queries[j][i];
            if (in_tree[no[j]]) {
                any = true;
            }
        }

        if (!any) {
            printf("Connected\n");
            continue;
        }

        memset(used, 0, m);
        for (int j = 0; j < c; j++) {
            used[no[j]] = true;
        }

        for (int j = 0; j < m; j++) {
            if (used[j])
                continue;

            uf.unite(xs[j], ys[j]);
        }

        if (uf.size(0) == n) {
            printf("Connected\n");
        } else {
            printf("Disconnected\n");
        }
    }
}

