#include <iostream>
#include <cstdio>
#include <algorithm>
#include <vector>
#include <cstring>
using namespace std;

struct union_find {
    int *p;
    union_find(int n) {
        p = new int[n];
        memset(p, -1, n * sizeof(int));
    }

    int find(int x) {
        return p[x] < 0 ? x : p[x] = find(p[x]);
    }

    bool unite(int x, int y) {
        int xp = find(x),
            yp = find(y);

        if (xp == yp) return false;
        if (p[xp] < p[yp]) p[xp] += p[yp], p[yp] = xp;
        else p[yp] += p[xp], p[xp] = yp;
        return true;
    }
    int size(int x) {
        return -p[find(x)];
    }
};

void readn(register int *n) {
    register char c;
    *n = 0;
    while (true) {
        //c = getc_unlocked(stdin);
        c = getc(stdin);
        switch (c) {
            case ' ': 
            case '\n': 
                return;
            default:
                *n = *n * 10 + c - '0';
                break;
        }
    }
}

vector<int> *adj;
int *dnum, *dlow;
bool *visited;
int viscnt = 0;

void dfs(int at, int parent) {
    if (visited[at]) {
        return;
    }

    dnum[at] = viscnt++;
    visited[at] = true;
    dlow[at] = dnum[at];

    for (int i = 0; i < adj[at].size(); i++) {
        int nxt = adj[at][i];
        if (nxt == parent)
            continue;
        bool vis = visited[nxt];
        dfs(nxt, at);
        if (vis) {
            dlow[at] = min(dlow[at], dnum[nxt]);
        } else {
            dlow[at] = min(dlow[at], dlow[nxt]);
        }
    }
}

int main() {
    int n, m;
    readn(&n);
    readn(&m);

    visited = new bool[n];
    memset(visited, 0, n);
    dnum = new int[n];
    dlow = new int[n];

    adj = new vector<int>[n];

    int *xs = new int[m];
    int *ys = new int[m];
    for (int i = 0; i < m; i++) {
        readn(xs + i);
        readn(ys + i);
        xs[i]--;
        ys[i]--;
        adj[xs[i]].push_back(ys[i]);
        adj[ys[i]].push_back(xs[i]);
    }

    bool *used = new bool[m];
    bool *in_tree = new bool[m];
    pair<int, int> *occ = new pair<int, int>[m];
    memset(in_tree, 0, m);

    for (int i = 0; i < m; i++) {
        occ[i].second = i;
    }

    dfs(0, -1);
    /*
    for (int i = 0; i < n; i++) {
        printf("%d %d %d\n", i+1, dnum[i]+1, dlow[i]+1);
    }
    return 0;
    */

    bool *bridge = new bool[m];
    for (int i = 0; i < m; i++) {
        bridge[i] = false;
        int a = xs[i],
            b = ys[i];

        //printf("%d %d: %d %d, %d %d\n", a, b, dnum[a], dlow[a], dnum[b], dlow[b]);


        if (dnum[a] < dnum[b]) {
            if (dlow[b] == dnum[b]) {
                bridge[i] = true;
            }
        } else {
            if (dlow[a] == dnum[a]) {
                bridge[i] = true;
            }
        }

        /*
        if (bridge[i]) {
            printf("bridge\n");
        } else {
            printf("not a bridge\n");
        }
        */
    }

    int cnt;
    readn(&cnt);

    int *queries[5];
    for (int i = 0; i < 5; i++) {
        queries[i] = new int[cnt];
    }

    for (int i = 0; i < cnt; i++) {
        int c;
        readn(&c);
        queries[4][i] = c;

        for (int j = 0; j < c; j++) {
            readn(&queries[j][i]);
            queries[j][i]--;
            occ[queries[j][i]].first++;
        }

    }

    sort(occ, occ + m);

    union_find uf(n);
    for (int i = 0, es = 0; i < m && es < n - 1; i++) {
        int a = xs[occ[i].second],
            b = ys[occ[i].second];

        if (uf.find(a) != uf.find(b)) {
            uf.unite(a, b);
            in_tree[occ[i].second] = true;
            es++;
        }
    }

    int no[4];
    for (int i = 0; i < cnt; i++) {
        memset(uf.p, -1, n * sizeof(int));

        int c = queries[4][i];

        bool any = false;
        bool b = false;

        for (int j = 0; j < c; j++) {
            no[j] = queries[j][i];
            if (in_tree[no[j]]) {
                any = true;
            }
            if (bridge[no[j]]) {
                b = true;
            }
        }

        if (b) {
            printf("Disconnected\n");
            continue;
        }
        if (!any) {
            printf("Connected\n");
            continue;
        }

        memset(used, 0, m);
        for (int j = 0; j < c; j++) {
            used[no[j]] = true;
        }

        for (int j = 0; j < m; j++) {
            if (used[j])
                continue;

            uf.unite(xs[j], ys[j]);
        }

        if (uf.size(0) == n) {
            printf("Connected\n");
        } else {
            printf("Disconnected\n");
        }
    }
}

