// Probabilistic solution of desperation

#include <iostream>
#include <vector>
#include <algorithm>
#include <random>
#include <unordered_set>

using namespace std;

int parent[10000];
int n, m;
vector<pair<int, int>> edges;

const int C = 80;
unordered_set<int> fail[C];

mt19937 rng(151345);

int find(int x) {
	if(parent[x] != x) {
		parent[x] = find(parent[x]);
	}
	return parent[x];
}

uniform_int_distribution<int> dist(0, 1);

void merge(int x, int y) {
	 x = find(x);
	 y = find(y);
	 parent[x] = y;
}

int main() {
	cin.sync_with_stdio(false);
	
	cin >> n >> m;
	for(int i = 0; i < m; ++i) {
		int a, b;
		cin >> a >> b;
		--a;
		--b;
		edges.emplace_back(a, b);
	}
	
	vector<int> edgeorder(m);
	for(int i = 0; i < m; ++i) edgeorder[i] = i;
	
	for(int c = 0; c < C; ++c) {
		for(int i = 0; i < n; ++i) parent[i] = i;
		shuffle(edgeorder.begin(), edgeorder.end(), rng);
		
		for(int edge : edgeorder) {
			if(find(edges[edge].first) != find(edges[edge].second)) {
				fail[c].insert(edge);
				merge(edges[edge].first, edges[edge].second);
			}
		}
	}
	
	int k;
	cin >> k;
	for(int i = 0; i < k; ++i) {
		int cnt;
		cin >> cnt;
		int F[4];
		for(int j = 0; j < cnt; ++j) {
			cin >> F[j];
			--F[j];
		}
		
		bool found = false;
		for(int c = 0; c < C; ++c) {
			bool ok = true;
			for(int j = 0; j < cnt; ++j) {
				if(fail[c].count(F[j])) {
					ok = false;
					break;
				}
			}
			if(ok) {
				found = true;
				break;
			}
		}
		
		if(found) {
			cout << "Connected\n";
		} else {
			cout << "Disconnected\n";
		}
	}
	
	return 0;
}
