#include <iostream>
#include <fstream>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <iomanip>
#include <algorithm>

#define TASK "task"
#define iters 24

typedef long long ll;
typedef long double ld;

using namespace std;

vector<int> edges[10000];
set< pair<int, int> > trees[iters];
bool disc[10000];
vector< pair<int, int> > edgePairs;
vector<int> rem;
set<int> goodEdges;

void dfs (int v, int iter)
{
	disc[v] = true;

	if (edges[v].size() < 200)
		random_shuffle(edges[v].begin(), edges[v].end());
	else
		random_shuffle(edges[v].begin(), edges[v].begin() + 200);

	for (int i = 0; i < edges[v].size(); i++)
	{
		if (!disc[edges[v][i]])
		{
			dfs(edges[v][i], iter);
			trees[iter].insert(make_pair(v, edges[v][i]));
			trees[iter].insert(make_pair(edges[v][i], v));
		}
	}
}

void dfsSmall (int v)
{
	disc[v] = true;

	for (int i = 0; i < edges[v].size(); i++)
	{
		bool usedEdge = true;
		for (int j = 0; j < rem.size(); j++)
		{
			if (edgePairs[rem[j]] == make_pair(v, edges[v][i]) || edgePairs[rem[j]] == make_pair(edges[v][i], v))
			{
				usedEdge = false;
				break;
			}
		}

		if (!usedEdge)
			continue;

		if (!disc[edges[v][i]])
			dfsSmall(edges[v][i]);
	}
}

int main() {
	//freopen(TASK".in", "r", stdin);
	//freopen(TASK".out", "w", stdout);

	srand(time(NULL));

	int n, m;
	cin >> n >> m;

	for (int i = 0; i < m; i++)
	{
		int a, b;
		cin >> a >> b;
		a--; b--;

		edgePairs.push_back(make_pair(a, b));
		edges[a].push_back(b);
		edges[b].push_back(a);
	}

	for (int i = 0; i < iters; i++)
	{
		memset(disc, 0, sizeof(disc));
		dfs(rand() % n, i);
	}

	/*for (int i = 0; i < 5; i++)
	{
		cout << "tree " << i + 1 << endl;
		set< pair<int, int> >::iterator it;
		for (it = trees[i].begin(); it != trees[i].end(); it++)
		{
			cout << (*it).first + 1 << ' ' << (*it).second + 1 << endl;
		}
	}*/

	int k;
	cin >> k;

	for (int i = 0; i < k; i++)
	{
		int c;
		cin >> c;

		rem.clear();
		for (int j = 0; j < c; j++)
		{
			int p;
			cin >> p;
			p--;
			rem.push_back(p);
		}

		bool isTree = false;
		for (int j = 0; j < iters; j++)
		{
			bool good = true;
			for (int k = 0; k < rem.size(); k++)
			{
				if (trees[j].find(edgePairs[rem[k]]) != trees[j].end())
				{
					good = false;
					break;
				}
			}
			if (good)
			{
				isTree = true;
				break;
			}
		}

		if (isTree)
		{
			cout << "Connected" << endl;
		}
		else
		{
			if (m > 8000)
			{
				cout << "Disconnected" << endl;
			} else
			{
				memset(disc, 0, sizeof(disc));
				dfsSmall(0);

				bool allDisc = true;
				for (int j = 0; j < n; j++)
				{
					if (!disc[j])
					{
						allDisc = false;
						break;
					}
				}

				if (allDisc)
				{
					cout << "Connected" << endl;
				}
				else
					cout << "Disconnected" << endl;
			}
		}
	}
	
	return 0;
}